<html>
	<head>
		<title>::TITLE::</title>
		<link rel="stylesheet" type="text/css" href="style.css" />
	</head>
	<body>
		<div id="content">
			<h1>::TITLE::</h1>
			<h2>::TITLE_SLIDE::</h2>
			<a href="::NEXT_PATH::"><img src="::IMAGE_PATH::" class="slide"/></a>
			<div id="container">
				<div id="next">
					<a href="::NEXT_PATH::">Next &gt;</a>
					<a href="::LAST_PATH::">Last &gt;&gt;</a>
				</div>
				<div id="previous">
					<a href="::FIRST_PATH::">&lt;&lt; First</a>
					<a href="::PREVIOUS_PATH::">&lt; Previous</a>
				</div>
				<div id="menu">
					<a href="index.html">Table of content</a>
				</div>
				<div class="infos">
					<p id="author">Author: ::AUTHOR::<p>
					<p id="position">Slide <em>::SLIDE_NUM::</em> of <em>::NB_SLIDES::</em><p>
				</div>
			</div>
		</div>
	</body>
</html>
