<html>
	<head>
		<title>::TITLE::</title>
		<link rel="stylesheet" type="text/css" href="style.css" />
	</head>
	<body>
		<div id="content">
			<h1>::TITLE::</h1>
            <h2>Table of content</h2>
            ::TOC::
			<div id="container">
				<div class="infos">
					<p id="author">Author: ::AUTHOR::<p>
				</div>
			</div>
		</div>
	</body>
</html>
