<?xml version="1.0" encoding="UTF-8" ?>
<gui name="roundcornersplugin" 
     library="karbon_roundcornersplugin" 
     version="1"
     xmlns="http://www.kde.org/standards/kxmlgui/1.0"
     xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
     xsi:schemaLocation="http://www.kde.org/standards/kxmlgui/1.0
                         http://www.kde.org/standards/kxmlgui/1.0/kxmlgui.xsd" >
<MenuBar>
    <Menu name="effects">
        <Action name="path_round_corners"/>
    </Menu>
</MenuBar>
<ToolBar name="Effects" hidden="true">
    <Action name="path_round_corners"/>
</ToolBar>
</gui>
